pyxmpp2.interfaces.XMPPFeatureHandler

Package pyxmpp2 :: Module interfaces :: Class XMPPFeatureHandler |
[hide private]

# Class XMPPFeatureHandler

Base class for objects handling incoming stanzas.

The subclasses should provide methods decorated with one of:

> - iq_get_stanza_handler: for methods handling `<iq type="get"/>` stanzas.
> - iq_set_stanza_handler: for methods handling `<iq type="set"/>` stanzas.
> - message_stanza_handler: for methods handling `<message />` stanzas
> - presence_stanza_handler: for methods handling `<presence />` stanzas

Nested Classes | [hide private]
| __metaclass__ Metaclass for defining Abstract Base Classes (ABCs).

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| __abstractmethods__ = ``frozenset([``])``
| _abc_cache = `<_weakrefset.WeakSet object at 0x85cacec>`
| _abc_negative_cache = `<_weakrefset.WeakSet object at 0x85cad2c>`
| _abc_negative_cache_version = `10`
| _abc_registry = `<_weakrefset.WeakSet object at 0x85cac8c>`

Properties | [hide private]
Inherited from `object`: `__class__`